#! /bin/sh

######################################################################
#                                                                    #
#  Web antenna for IP range information                              #
#                                                                    #
#  Usage: wantenna.sh [mailto]                                       #
#         If you specified "mailto" argument, the report will be     #
#         send to the e-mail address "mailto" only when it needs     #
#         to report.                                                 #
#                                                                    #
######################################################################


# ====================================================================
#  Definitions
# ====================================================================

# ===== Target URLs =====
#
URLs="                                                        \
  http://www.nttdocomo.co.jp/mc-user/i/ip.html                \
  http://www.dp.j-phone.com/dp/tech_svc/web/ip.php            \
  http://www.ddipocket.co.jp/p_s/products/airh_phone/ip.html  \
  http://www.au.kddi.com/ezfactory/tec/spec/ezsava_ip.html    \
"

# ===== User Configurations =====
#
DIR_DOWNLOADTO="`dirname $0`/work"
MAILTO="$1"
SUBJECT="Web antenna report"

# ===== Depending Commands =====
#
CMD_WGET="/usr/local/bin/wget"
CMD_MD5=`which md5`     # for *BSD
#CMD_MD5=`which md5sum`  # for Linux
CMD_MAIL=`which mail`


# ====================================================================
#  Routines
# ====================================================================

# ===== Preparation =====
#
mkdir -p $DIR_DOWNLOADTO
if [ $? -ne 0 ]; then
  echo "Cannot make a work directory since no mail address specified!" 1>&2
  exit 1
fi
tempfile=`mktemp /tmp/antenna_temp.XXXX`
if [ -z "$tempfile" ]; then
  echo "Cannot make a temporary file!" 1>&2
  exit 1
fi
echo "Hello, this is Web Antenna." >> $tempfile
echo >> $tempfile
need_to_notify="NO"

# ===== Main =====
#
if [ \( -x "$CMD_WGET" \) -a \( -x "$CMD_MD5" \) ]; then
  echo "Some pages got into the state where it is should be reported:" \
       >> $tempfile
  # --- use proxy or not ---
  if [ -n "$HTTP_PROXY" ]; then
    CMD_WGET="env http_proxy=$HTTP_PROXY $CMD_WGET --proxy=on"
  fi
  # --- wgetting ---
  for url in $URLs; do
    # --- (preparing) ---
    status=""
    filename="${url##*/}"
    subdir="${url#*//}"
    subdir="${subdir%/*}"
    mkdir -p $DIR_DOWNLOADTO/$subdir
    if [ -f "$DIR_DOWNLOADTO/$subdir/$filename" ]; then
      md5code_old=`cat "$DIR_DOWNLOADTO/$subdir/$filename" | $CMD_MD5`
    else
      md5code_old=""
    fi
    result=`$CMD_WGET --cache=off --timestamping --tries=3 \
                      --directory-prefix=$DIR_DOWNLOADTO/$subdir $url 2>&1`
    # --- (ckecking) ---
    # notice:
    #  This check may not be accept with a newer version than wget 1.8.2
    if   [ -n "`echo "$result" | grep "$filename. saved"`" ]; then
      if [ -f "$DIR_DOWNLOADTO/$subdir/$filename" ]; then
        md5code_new=`cat "$DIR_DOWNLOADTO/$subdir/$filename" | $CMD_MD5`
      else
        md5code_new=""
      fi
      if [ \( -n "$md5code_new" \) -a \( -n "$md5code_old" \) -a \
           \( "$md5code_new" = "$md5code_old" \) ]; then
        status="NOT_UPDATED"
      else
        status="UPDATED"
      fi
    elif [ -n "`echo "$result" | grep "no newer than local file"`" ]; then
      status="NOT_UPDATED"
    elif [ -n "`echo "$result" | grep "404 Not Found"`" ]; then
      status="NOT_FOUND"
    else
      status="ACCESS_ERROR"
    fi
    # --- (making a report message) ---
    if   [ "$status" = "UPDATED" ]; then
      echo "Updated: $url" >> $tempfile
      need_to_notify="YES"
    elif [ "$status" = "NOT_FOUND" ]; then
      echo "Maybe moved or deleted: $url" >> $tempfile
      need_to_notify="YES"
    elif [ "$status" = "ACCESS_ERROR" ]; then
      echo "Access failed: $url" >> $tempfile
      need_to_notify="YES"
    #elif [ "$status" = "NOT_UPDATED" ]; then
    #else
    fi
  done
else
  echo \
  "This program depends on the following software(s) which is not installed." \
  >> $tempfile
  for filename in $CMD_WGET $CMD_MD5; do
    [ -x "$filename" ] || echo "  `basename $filename`" >> $tempfile
  done
  need_to_notify="YES"
fi

# ===== Post Handling =====
#
if [ \( -n "$MAILTO" \) -a \( -x "$CMD_MAIL" \) ]; then
  if [ "$need_to_notify" = "YES" ]; then
    if [ -n "$SUBJECT" ]; then
      cat $tempfile | $CMD_MAIL -s "$SUBJECT" $MAILTO
    else
      cat $tempfile | $CMD_MAIL $MAILTO
    fi
  fi
else
  if [ "$need_to_notify" = "YES" ]; then
    cat $tempfile
  else
    echo "All of web pages are not updated. Nothing to report to you."
  fi
  [ -n "$MAILTO" ] && echo \
  "(I could not report that with e-mail since "mail" command is not available.)"
fi
rm $tempfile
